##  Filtering and Searching in the Discovery Inbox
Choose Filter to apply different criteria to the discovered SAP list items. Available filter criteria include:
Filter Criteria | Description
---|---
Status | Filter the list by the status of the discovered item, including Linked, Action needed, or Rejected. This helps you identify items that need your attention or review services you’ve already linked or rejected.
Business capability | Filter by the business capability fact sheet suggested for discovered AI agents.
Integration | Filter by integration name, such as Microsoft Entra ID. This allows you to review all tenants of a specific integration at once.
Classification | Filter items by type: AI agent or MCP server.
Action By | Filter the list by the user or system that linked the discovered items to fact sheets.
Agent Created By | Filter AI agents by the Microsoft platform they were built on: Copilot Studio or Microsoft Foundry.
Account Enabled | Filter by the availability status of AI agents discovered from Microsoft Entra ID.
Creation Timestamp | Filter by the date when the item was created in the source system.


